==> dynamodb-0.8.2-sources.jar: software/amazon/awscdk/services/dynamodb/TableStreamArn.java <==
package software.amazon.awscdk.services.dynamodb;
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.dynamodb.$Module.class, fqn = "@aws-cdk/aws-dynamodb.TableStreamArn")
public class TableStreamArn extends software.amazon.awscdk.Arn {
    protected TableStreamArn(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     * @param displayName A human-readable display hint for this Token
     */
    public TableStreamArn(@javax.annotation.Nullable final java.lang.Object valueOrFunction, @javax.annotation.Nullable final java.lang.String displayName) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(valueOrFunction), java.util.stream.Stream.of(displayName)).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     */
    public TableStreamArn(@javax.annotation.Nullable final java.lang.Object valueOrFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(valueOrFunction).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     */
    public TableStreamArn() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }
}

==> dynamodb-0.9.0-sources.jar: software/amazon/awscdk/services/dynamodb/TableStreamArn.java <==
package software.amazon.awscdk.services.dynamodb;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:56:31.779Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.dynamodb.$Module.class, fqn = "@aws-cdk/aws-dynamodb.TableStreamArn")
public class TableStreamArn extends software.amazon.awscdk.Arn {
    protected TableStreamArn(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     * @param displayName A human-readable display hint for this Token
     */
    public TableStreamArn(final java.lang.Object valueOrFunction, @javax.annotation.Nullable final java.lang.String displayName) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(valueOrFunction, "valueOrFunction is required")), java.util.stream.Stream.of(displayName)).toArray());
    }
    /**
     * Creates a token that resolves to `value`.
     * 
     * If value is a function, the function is evaluated upon resolution and
     * the value it returns will be used as the token's value.
     * 
     * displayName is used to represent the Token when it's embedded into a string; it
     * will look something like this:
     * 
     *       "embedded in a larger string is ${Token[DISPLAY_NAME.123]}"
     * 
     * This value is used as a hint to humans what the meaning of the Token is,
     * and does not have any effect on the evaluation.
     * 
     * Must contain only alphanumeric and simple separator characters (_.:-).
     * @param valueOrFunction What this token will evaluate to, literal or function.
     */
    public TableStreamArn(final java.lang.Object valueOrFunction) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(java.util.Objects.requireNonNull(valueOrFunction, "valueOrFunction is required")).toArray());
    }
}
